@@ -1,9 +1,9 @@
-C Output from Public domain Ratfor, version 1.01
+C Output from Public domain Ratfor, version 1.0
       subroutine dqrls(x,dx,pivot,qraux,y,dy,beta,res,qt,tol,scrtch,rank
      *)
-      integer pivot(1),dx(2),dy(2),rank
-      double precision x(1), qraux(1), y(1), beta(1),res(1),qt(1),tol(1)
-     *, scrtch(1)
+      integer pivot(*),dx(2),dy(2),rank
+      double precision x(*), qraux(*), y(*), beta(*),res(*),qt(*),tol(*)
+     *, scrtch(*)
       integer n,p,q,kn,kp,k,info
       n=dx(1)
       p=dx(2)
@@ -25,7 +25,7 @@ C Output from Public domain Ratfor, version 1.01
       return
       end
       subroutine dqrsl1(qr,dq,qra,rank,y,k,qy,qb,job,info)
-      double precision qr(1),qra(1),y(1),qy(1),qb(1)
+      double precision qr(*),qra(*),y(*),qy(*),qb(*)
       integer dq(2),job,k,rank
       integer n,kn,kb,j
       double precision ourqty(1), ourqy(1), ourb(1), ourrsd(1), ourxb(1)
@@ -104,8 +104,8 @@ C Output from Public domain Ratfor, version 1.01
       return
       end
       subroutine dqr(x,dx,pivot,qraux,tol,scrtch,rank)
-      integer pivot(1),dx(2),rank
-      double precision x(1), qraux(1), tol(1), scrtch(1)
+      integer pivot(*),dx(2),rank
+      double precision x(*), qraux(*), tol(*), scrtch(*)
       integer n,p
       n=dx(1)
       p=dx(2)
@@ -114,8 +114,8 @@ C Output from Public domain Ratfor, version 1.01
       end
       subroutine dqrdca(x,ldx,n,p,qraux,jpvt,work,rank,eps)
       integer ldx,n,p,rank
-      integer jpvt(1)
-      double precision x(ldx,1),qraux(1),work(1),eps
+      integer jpvt(*)
+      double precision x(ldx,*),qraux(*),work(*),eps
       integer j,jj,jp,l,lup,curpvt
       double precision dnrm2,tt
       double precision ddot,nrmxl,t,ww
@@ -394,8 +394,8 @@ C Output from Public domain Ratfor, version 1.01
       return
       end
       subroutine chol(a,p,work,jpvt,job,info)
-      integer p,jpvt(1),job,info(1)
-      double precision a(p,1),work(1)
+      integer p,jpvt(*),job,info(*)
+      double precision a(p,*),work(*)
       integer i,j
       j =2
 23124 if(.not.(j.le.p))goto 23126
@@ -426,7 +426,7 @@ C Output from Public domain Ratfor, version 1.01
       return
       end
       subroutine crs(x,dmx,matz,w,z,fv1,fv2,ierr)
-      double precision x(1),w(1),z(1),fv1(1),fv2(1)
+      double precision x(*),w(*),z(*),fv1(*),fv2(*)
       integer dmx(2),nx,nv,ierr,matz
       nx=dmx(1)
       nv=dmx(2)
@@ -434,9 +434,9 @@ C Output from Public domain Ratfor, version 1.01
       return
       end
       subroutine dqrls2(x,dx,pivot,qraux,y,dy,beta,res,qt,scrtch,eps)
-      integer pivot(1),dx(2),dy(2)
-      double precision x(1), qraux(1), y(1), beta(1),res(1),qt(1), scrtc
-     *h(1),eps
+      integer pivot(*),dx(2),dy(2)
+      double precision x(*), qraux(*), y(*), beta(*),res(*),qt(*), scrtc
+     *h(*),eps
       integer n,p,q,kn,kp,k,info,rank
       n=dx(1)
       p=dx(2)
@@ -456,7 +456,7 @@ C Output from Public domain Ratfor, version 1.01
       return
       end
       subroutine dsvdc1(x,dmx,job,work,e,s,u,v,info)
-      double precision x(1),work(1),s(1),e(1),u(1),v(1)
+      double precision x(*),work(*),s(*),e(*),u(*),v(*)
       integer dmx(2),nx,nv,job,info
       nx=dmx(1)
       nv=dmx(2)
@@ -1783,7 +1783,7 @@ C Output from Public domain Ratfor, version 1.01
       end
       subroutine dmatp(x,dx,y,dy,z)
       integer dx(2),dy(2)
-      double precision x(1), y(1),z(1),ddot
+      double precision x(*), y(*),z(*),ddot
       integer n,p,q,i,j
       n=dx(1)
       p=dx(2)
@@ -1805,7 +1805,7 @@ C Output from Public domain Ratfor, version 1.01
       end
       subroutine dmatpt(x,dx,y,dy,z)
       integer dx(2),dy(2)
-      double precision x(1), y(1),z(1),ddot
+      double precision x(*), y(*),z(*),ddot
       integer n,p,q,i,j,ii
       n=dx(1)
       p=dx(2)
@@ -1829,9 +1829,9 @@ C Output from Public domain Ratfor, version 1.01
       end
       subroutine matpm(x,dx,mmx,mx,y,dy,mmy,my,z)
       integer dx(2),dy(2)
-      integer mmx(1), mmy(1)
-      integer mx(1), my(1)
-      double precision x(1), y(1),z(1),ddot
+      integer mmx(*), mmy(*)
+      integer mx(*), my(*)
+      double precision x(*), y(*),z(*),ddot
       integer n,p,q,i,j
       n=dx(1)
       p=dx(2)
@@ -1857,9 +1857,9 @@ C Output from Public domain Ratfor, version 1.01
       end
       subroutine matptm(x,dx,mmx,mx,y,dy,mmy,my,z)
       integer dx(2),dy(2)
-      integer mmx(1), mmy(1)
-      integer mx(1), my(1)
-      double precision x(1), y(1),z(1),ddot
+      integer mmx(*), mmy(*)
+      integer mx(*), my(*)
+      double precision x(*), y(*),z(*),ddot
       integer n,p,q,i,j
       call colmis(mmx,dx(1),dx(2),mx)
       call colmis(mmy,dy(1),dy(2),my)
@@ -1888,7 +1888,7 @@ C Output from Public domain Ratfor, version 1.01
       subroutine rowmis(m,n,p,vec)
       integer n,p
       integer m(n,p)
-      integer vec(1)
+      integer vec(*)
       do23659 i = 1,n 
       vec(i)=0
       do23661 j = 1,p 
@@ -1904,7 +1904,7 @@ C Output from Public domain Ratfor, version 1.01
       subroutine colmis(m,n,p,vec)
       integer n,p
       integer m(n,p)
-      integer vec(1)
+      integer vec(*)
       do23665 j = 1,p 
       vec(j)=0
       do23667 i = 1,n 
@@ -1915,301 +1915,6 @@ C Output from Public domain Ratfor, version 1.01
 23668 continue
 23665 continue
 23666 continue
-      return
-      end
-      subroutine daxpy(n,da,dx,incx,dy,incy)
-      double precision dx(1),dy(1),da
-      integer i,incx,incy,m,mp1,n
-      if(n.gt.0)then
-      if(da.ne.0.0d0)then
-      if(incx.ne.1.or.incy.ne.1)then
-      ix = 1
-      iy = 1
-      if(incx.lt.0)then
-      ix = (-n+1)*incx+1
-      endif
-      if(incy.lt.0)then
-      iy = (-n+1)*incy+1
-      endif
-      do23681 i = 1,n 
-      dy(iy) = dy(iy)+da*dx(ix)
-      ix = ix+incx
-      iy = iy+incy
-23681 continue
-23682 continue
-      else
-      m = mod(n,4)
-      if(m.ne.0)then
-      do23685 i = 1,m
-      dy(i) = dy(i)+da*dx(i)
-23685 continue
-23686 continue
-      if(n.lt.4)then
-      return
-      endif
-      endif
-      mp1 = m+1
-      do23689 i = mp1,n,4 
-      dy(i) = dy(i)+da*dx(i)
-      dy(i+1) = dy(i+1)+da*dx(i+1)
-      dy(i+2) = dy(i+2)+da*dx(i+2)
-      dy(i+3) = dy(i+3)+da*dx(i+3)
-23689 continue
-23690 continue
-      endif
-      endif
-      endif
-      return
-      end
-      subroutine dcopy(n,dx,incx,dy,incy)
-      double precision dx(1),dy(1)
-      integer i,incx,incy,ix,iy,m,mp1,n
-      if(n.gt.0)then
-      if(incx.ne.1.or.incy.ne.1)then
-      ix = 1
-      iy = 1
-      if(incx.lt.0)then
-      ix = (-n+1)*incx+1
-      endif
-      if(incy.lt.0)then
-      iy = (-n+1)*incy+1
-      endif
-      do23699 i = 1,n 
-      dy(iy) = dx(ix)
-      ix = ix+incx
-      iy = iy+incy
-23699 continue
-23700 continue
-      else
-      m = mod(n,7)
-      if(m.ne.0)then
-      do23703 i = 1,m
-      dy(i) = dx(i)
-23703 continue
-23704 continue
-      if(n.lt.7)then
-      return
-      endif
-      endif
-      mp1 = m+1
-      do23707 i = mp1,n,7 
-      dy(i) = dx(i)
-      dy(i+1) = dx(i+1)
-      dy(i+2) = dx(i+2)
-      dy(i+3) = dx(i+3)
-      dy(i+4) = dx(i+4)
-      dy(i+5) = dx(i+5)
-      dy(i+6) = dx(i+6)
-23707 continue
-23708 continue
-      endif
-      endif
-      return
-      end
-      double precision function ddot(n,dx,incx,dy,incy)
-      double precision dx(1),dy(1),dtemp
-      integer i,incx,incy,ix,iy,m,mp1,n
-      ddot = 0.0d0
-      dtemp = 0.0d0
-      if(n.gt.0)then
-      if(incx.eq.1.and.incy.eq.1)then
-      m = mod(n,5)
-      if(m.ne.0)then
-      do23715 i = 1,m
-      dtemp = dtemp+dx(i)*dy(i)
-23715 continue
-23716 continue
-      if(n.lt.5)then
-      go to 10
-      endif
-      endif
-      mp1 = m+1
-      do23719 i = mp1,n,5
-      dtemp = dtemp+dx(i)*dy(i)+dx(i+1)*dy(i+1)+dx(i+2)*dy(i+2)+dx(i+3)*
-     *dy(i+3)+dx(i+4)*dy(i+4)
-23719 continue
-23720 continue
-10    ddot = dtemp
-      else
-      ix = 1
-      iy = 1
-      if(incx.lt.0)then
-      ix = (-n+1)*incx+1
-      endif
-      if(incy.lt.0)then
-      iy = (-n+1)*incy+1
-      endif
-      do23725 i = 1,n 
-      dtemp = dtemp+dx(ix)*dy(iy)
-      ix = ix+incx
-      iy = iy+incy
-23725 continue
-23726 continue
-      ddot = dtemp
-      endif
-      endif
-      return
-      end
-      double precision function dnrm2(n,dx,incx)
-      integer nst
-      double precision dx(1),cutlo,cuthi,hitest,sum,xmax,zero,one
-      data zero,one/0.0d0,1.0d0/
-      data cutlo,cuthi/8.232d-11,1.304d19/
-      if(n.le.0)then
-      dnrm2 = zero
-      else
-      nst = 20
-      sum = zero
-      nn = n*incx
-      i = 1
-23729 continue
-      if(nst .eq. 20)then
-      goto 20
-      else
-      if(nst .eq. 30)then
-      goto 30
-      else
-      if(nst .eq. 40)then
-      goto 40
-      else
-      if(nst .eq. 80)then
-      goto 80
-      endif
-      endif
-      endif
-      endif
-20    if(dabs(dx(i)).gt.cutlo)then
-      go to 50
-      endif
-      nst = 30
-      xmax = zero
-30    if(dx(i).eq.zero)then
-      go to 100
-      endif
-      if(dabs(dx(i)).gt.cutlo)then
-      go to 50
-      endif
-      nst = 40
-      go to 70
-40    if(dabs(dx(i)).le.cutlo)then
-      go to 80
-      endif
-      sum = (sum*xmax)*xmax
-50    hitest = cuthi/float(n)
-      do23748 j = i,nn,incx 
-      if(dabs(dx(j)).ge.hitest)then
-      go to 60
-      endif
-      sum = sum+dx(j)**2
-23748 continue
-23749 continue
-      goto 23731
-60    i = j
-      nst = 80
-      sum = (sum/dx(i))/dx(i)
-70    xmax = dabs(dx(i))
-      go to 90
-80    if(dabs(dx(i)).gt.xmax)then
-      sum = one+sum*(xmax/dx(i))**2
-      xmax = dabs(dx(i))
-      go to 100
-      endif
-90    sum = sum+(dx(i)/xmax)**2
-100   i = i+incx
-      if(i.gt.nn)then
-      go to 110
-      endif
-23730 goto 23729
-23731 continue
-      dnrm2 = dsqrt(sum)
-      return
-110   dnrm2 = xmax*dsqrt(sum)
-      endif
-      return
-      end
-      subroutine dscal(n,da,dx,incx)
-      double precision da,dx(1)
-      integer i,incx,m,mp1,n,nincx
-      if(n.gt.0)then
-      if(incx.ne.1)then
-      nincx = n*incx
-      do23760 i = 1,nincx,incx
-      dx(i) = da*dx(i)
-23760 continue
-23761 continue
-      else
-      m = mod(n,5)
-      if(m.ne.0)then
-      do23764 i = 1,m
-      dx(i) = da*dx(i)
-23764 continue
-23765 continue
-      if(n.lt.5)then
-      return
-      endif
-      endif
-      mp1 = m+1
-      do23768 i = mp1,n,5 
-      dx(i) = da*dx(i)
-      dx(i+1) = da*dx(i+1)
-      dx(i+2) = da*dx(i+2)
-      dx(i+3) = da*dx(i+3)
-      dx(i+4) = da*dx(i+4)
-23768 continue
-23769 continue
-      endif
-      endif
-      return
-      end
-      subroutine dswap(n,dx,incx,dy,incy)
-      double precision dx(1),dy(1),dtemp
-      integer i,incx,incy,ix,iy,m,mp1,n
-      if(n.gt.0)then
-      if(incx.ne.1.or.incy.ne.1)then
-      ix = 1
-      iy = 1
-      if(incx.lt.0)then
-      ix = (-n+1)*incx+1
-      endif
-      if(incy.lt.0)then
-      iy = (-n+1)*incy+1
-      endif
-      do23778 i = 1,n 
-      dtemp = dx(ix)
-      dx(ix) = dy(iy)
-      dy(iy) = dtemp
-      ix = ix+incx
-      iy = iy+incy
-23778 continue
-23779 continue
-      else
-      m = mod(n,3)
-      if(m.ne.0)then
-      do23782 i = 1,m 
-      dtemp = dx(i)
-      dx(i) = dy(i)
-      dy(i) = dtemp
-23782 continue
-23783 continue
-      if(n.lt.3)then
-      return
-      endif
-      endif
-      mp1 = m+1
-      do23786 i = mp1,n,3 
-      dtemp = dx(i)
-      dx(i) = dy(i)
-      dy(i) = dtemp
-      dtemp = dx(i+1)
-      dx(i+1) = dy(i+1)
-      dy(i+1) = dtemp
-      dtemp = dx(i+2)
-      dx(i+2) = dy(i+2)
-      dy(i+2) = dtemp
-23786 continue
-23787 continue
-      endif
-      endif
       return
       end
       subroutine dshift(x,ldx,n,j,k)
@@ -2230,8 +1935,8 @@ C Output from Public domain Ratfor, version 1.01
       return
       end
       subroutine rtod(dx,dy,n)
-      real dx(1)
-      double precision dy(1)
+      real dx(*)
+      double precision dy(*)
       integer i,m,mp1,n
       if(n.gt.0)then
       m = mod(n,7)
@@ -2259,8 +1964,8 @@ C Output from Public domain Ratfor, version 1.01
       return
       end
       subroutine dtor(dx,dy,n)
-      double precision dx(1)
-      real dy(1)
+      double precision dx(*)
+      real dy(*)
       integer i,m,mp1,n
       if(n.gt.0)then
       m = mod(n,7)
@@ -2287,70 +1992,10 @@ C Output from Public domain Ratfor, version 1.01
       endif
       return
       end
-      subroutine drot(n,dx,incx,dy,incy,c,s)
-      double precision dx(1),dy(1),dtemp,c,s
-      integer i,incx,incy,ix,iy,n
-      if(n.gt.0)then
-      if(incx.eq.1.and.incy.eq.1)then
-      do23818 i = 1,n 
-      dtemp = c*dx(i)+s*dy(i)
-      dy(i) = c*dy(i)-s*dx(i)
-      dx(i) = dtemp
-23818 continue
-23819 continue
-      else
-      ix = 1
-      iy = 1
-      if(incx.lt.0)then
-      ix = (-n+1)*incx+1
-      endif
-      if(incy.lt.0)then
-      iy = (-n+1)*incy+1
-      endif
-      do23824 i = 1,n 
-      dtemp = c*dx(ix)+s*dy(iy)
-      dy(iy) = c*dy(iy)-s*dx(ix)
-      dx(ix) = dtemp
-      ix = ix+incx
-      iy = iy+incy
-23824 continue
-23825 continue
-      endif
-      endif
-      return
-      end
-      subroutine drotg(da,db,c,s)
-      double precision da,db,c,s,roe,scale,r,z
-      roe = db
-      if(dabs(da).gt.dabs(db))then
-      roe = da
-      endif
-      scale = dabs(da)+dabs(db)
-      if(scale.eq.0.0d0)then
-      c = 1.0d0
-      s = 0.0d0
-      r = 0.0d0
-      else
-      r = scale*dsqrt((da/scale)**2+(db/scale)**2)
-      r = dsign(1.0d0,roe)*r
-      c = da/r
-      s = db/r
-      endif
-      z = 1.0d0
-      if(dabs(da).gt.dabs(db))then
-      z = s
-      endif
-      if(dabs(db).ge.dabs(da).and.c.ne.0.0d0)then
-      z = 1.0d0/c
-      endif
-      da = r
-      db = z
-      return
-      end
       subroutine dqrsl(x,ldx,n,k,qraux,y,qy,qty,b,rsd,xb,job,info)
       integer ldx,n,k,job,info
-      double precision x(ldx,1),qraux(1),y(1),qy(1),qty(1),b(1),rsd(1),x
-     *b(1)
+      double precision x(ldx,*),qraux(*),y(*),qy(*),qty(*),b(*),rsd(*),x
+     *b(*)
       integer i,j,jj,ju,kp1
       double precision ddot,t,temp
       logical cb,cqy,cqty,cr,cxb
@@ -2475,7 +2120,7 @@ C Output from Public domain Ratfor, version 1.01
       end
       subroutine dsvdc(x,ldx,n,p,s,e,u,ldu,v,ldv,work,job,info)
       integer ldx,n,p,ldu,ldv,job,info
-      double precision x(ldx,1),s(1),e(1),u(ldu,1),v(ldv,1),work(1)
+      double precision x(ldx,*),s(*),e(*),u(ldu,*),v(ldv,*),work(*)
       integer i,iter,j,jobu,k,kase,kk,l,ll,lls,lm1,lp1,ls,lu,m,maxit,mm,
      *mm1,mp1,nct,nctp1,ncu,nrt,nrtp1
       double precision ddot,t
@@ -2853,7 +2498,7 @@ C Output from Public domain Ratfor, version 1.01
       end
       subroutine dtrsl(t,ldt,n,b,job,info)
       integer ldt,n,job,info
-      double precision t(ldt,1),b(1)
+      double precision t(ldt,*),b(*)
       double precision ddot,temp
       integer which,j,jj
       do24063 info = 1,n
